Package: stringstatic
Title: Dependency-Free String Operations
Version: 0.1.2
Authors@R: c(
    person("Alexander", "Rossell Hayes", , "alexander@rossellhayes.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0001-9412-0457")),
    person("Eli", "Pousson", , "eli.pousson@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0001-8280-1706", "str_pad() and str_split() functions")),
    person("Hadley", "Wickham", , "hadley@rstudio.com", role = c("ctb", "cph"),
           comment = "stringr package"),
    person("RStudio", role = "cph",
           comment = "stringr package")
  )
Description: Provides drop-in replacements for functions from the
    'stringr' package, with the same user interface. These functions have
    no external dependencies and can be copied directly into your package
    code using the 'staticimports' package.
License: CC0
URL: https://github.com/rossellhayes/stringstatic
BugReports: https://github.com/rossellhayes/stringstatic/issues
Suggests: testthat (>= 3.0.0)
Config/Needs/roxygen: wch/staticimports
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-07-11 06:09:41 UTC; alex
Author: Alexander Rossell Hayes [aut, cre, cph]
    (<https://orcid.org/0000-0001-9412-0457>),
  Eli Pousson [ctb] (<https://orcid.org/0000-0001-8280-1706>, str_pad()
    and str_split() functions),
  Hadley Wickham [ctb, cph] (stringr package),
  RStudio [cph] (stringr package)
Maintainer: Alexander Rossell Hayes <alexander@rossellhayes.com>
Repository: CRAN
Date/Publication: 2023-07-12 22:30:03 UTC
Built: R 4.6.0; ; 2026-04-25 22:38:37 UTC; unix
