# Generated by roxygen2: do not edit by hand

export(fixed)
export(regex)
export(str_c)
export(str_count)
export(str_detect)
export(str_dup)
export(str_ends)
export(str_extract)
export(str_extract_all)
export(str_length)
export(str_match)
export(str_pad)
export(str_remove)
export(str_remove_all)
export(str_replace)
export(str_replace_all)
export(str_replace_na)
export(str_split)
export(str_split_fixed)
export(str_squish)
export(str_starts)
export(str_subset)
export(str_trim)
export(str_which)
export(str_width)
